==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/konsole/kdevkonsoleview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=This plugin provides KDevelop with an embedded konsole for quick and easy command line access.
Comment[bg]=Тaзи приставка осигурява на KDevelop вградена конзола за лесен достъп от команден ред.
Comment[bs]=Ovaj dodatak obezbjeđuje KDvelop sa ugrađenom konzolom za brz i lahak pristup komandnoj liniji.
Comment[ca]=Aquest connector proporciona a KDevelop un Konsole incrustat per accedir de manera ràpida i fàcil a la línia d'ordres.
Comment[ca@valencia]=Este connector proporciona a KDevelop un Konsole incrustat per accedir de manera ràpida i fàcil a la línia d'ordes.
Comment[da]=Dette plugin giver KDevelop en indlejret konsol for hurtig og nem kommandolinje adgang.
Comment[de]=Dieses Modul stattet KDevelop mit einer eingebetteten Konsole zum einfachen Zugriff auf die Befehlszeile aus.
Comment[el]=Αυτό το πρόσθετο προσφέρει στο KDevelop μια ενσωματωμένη konsole για γρήγορη και εύκολη πρόσβαση σε γραμμή εντολών.
Comment[en_GB]=This plugin provides KDevelop with an embedded konsole for quick and easy command line access.
Comment[es]=Este complemento proporciona a KDevelop una consola empotrada para acceder rápida y fácilmente a la línea de órdenes.
Comment[et]=See plugin pakub KDevelopile põimitud konsooli käsurea kiireks ja lihtsaks kasutamiseks.
Comment[fi]=Tämä liitännäinen tarjoaa KDevelop-ohjelmalle upotetun pääteikkunan nopeaan ja helppoon komentorivityöskentelyyn.
Comment[fr]=Ce module externe fournit à KDevelop une console intégrée permettant un accès rapide et aisé à la ligne de commande.
Comment[gl]=Este complemento fornécelle a KDevelop un konsole integrado para dispor de acceso rápido e sinxelo á liña de ordes.
Comment[hu]=Ez a bővítmény szolgáltatja a KDevelopot egy beágyazott konzollal a gyors és könnyű parancssori hozzáféréshez.
Comment[it]=Questa estensione dota KDevelop di una console integrata per una rapido e facile accesso alla riga di comando.
Comment[ja]=コマンドラインに簡単に素早くアクセスできるように KDevelop に組み込み Konsole を提供します
Comment[kk]=Бұл плагині KDevelop құрамына, тез және ыңғайлы командаларды орындау үшін konsole-ді ендіреді.
Comment[nb]=Dette programtillegget gir KDevelop en innebygget konsole for rask og lett tilgang til kommandolinja.
Comment[nds]=Dit Moduul stellt en inbett Konsole för KDevelop praat, wat gau un eenfach Togriep op de Konsool verlöövt.
Comment[nl]=Deze plugin biedt KDevelop een ingebed konsole voor snelle en gemakkelijke toegang tot commandoregels.
Comment[pl]=Ta wtyczka dodaje do KDevelopa wbudowaną konsolę umożliwiając szybki i łatwy dostęp do linii komend.
Comment[pt]=Este 'plugin' oferece ao KDevelop uma consola incorporada para um acesso rápido e simples à linha de comandos.
Comment[pt_BR]=Este plugin fornece ao KDevelop um terminal embutido para acesso rápido e fácil à linha de comando.
Comment[ru]=Это расширение добавляет в KDevelop встроенный терминал для быстрого и лёгкого доступа к командной строке.
Comment[sk]=Tento plugin poskytuje KDevelop so zabudovanou konzolou na rýchly a ľahký prístup k príkazovému riadku.
Comment[sl]=Vstavek v KDevelop prinaša vgrajeno konzolo za hiter in preprost dostop do ukazne vrstice.
Comment[sv]=Insticksprogrammet ger KDevelop en inbyggd terminal för snabb och enkel åtkomst av kommandoraden.
Comment[tr]=Bu eklenti, komut satırına kolayca erişebilmeniz için KDevelop içerisinde gömülü bir uçbirim sağlar.
Comment[uk]=За допомогою цього додатка у KDevelop можна буде скористатися вбудованою konsole, яка пришвидшить і полегшить доступ до командного рядка.
Comment[x-test]=xxThis plugin provides KDevelop with an embedded konsole for quick and easy command line access.xx
Comment[zh_CN]=此插件为 KDevelop 提供了一个快速方便地访问命令行的嵌入式控制台。
Comment[zh_TW]=此外掛程式提供 KDevelop 一個嵌入式的 konsole，能快速地使用命令列。
Name=Konsole Integration
Name[bg]=Интегриране на конзола
Name[bs]=Integracija konzole
Name[ca]=Integració del Konsole
Name[ca@valencia]=Integració del Konsole
Name[da]=Integration af Konsole
Name[de]=Konsole-Integration
Name[el]=Ενσωμάτωση Konsole
Name[en_GB]=Konsole Integration
Name[es]=Integración de la consola
Name[et]=Lõimimine Konsooliga
Name[fi]=Pääteikkunaintegraatio
Name[fr]=Intégration de Konsole
Name[gl]=Integración con Konsole
Name[hu]=Konsole integráció
Name[it]=Integrazione Konsole
Name[ja]=Konsole の統合
Name[kk]=Konsole біріктіруі
Name[nb]=Konsole-integrering
Name[nds]=Konsool-Inbinnen
Name[nl]=Console-integratie
Name[pl]=Integracja Konsoli
Name[pt]=Integração com o Konsole
Name[pt_BR]=Integração com o Konsole
Name[ru]=Интеграция Konsole
Name[sk]=Integrácia Konsole
Name[sl]=Vgrajena konzola
Name[sv]=Integrering av Konsole
Name[tr]=Konsole Bütünleşmesi
Name[ug]=Konsole يۈرۈشلەشتۈرۈلۈشى
Name[uk]=Інтеграція Konsole
Name[x-test]=xxKonsole Integrationxx
Name[zh_CN]=Konsole 整合
Name[zh_TW]=Konsole 整合
GenericName=Terminal Integration
GenericName[bg]=Интегриране на терминал
GenericName[bs]=Integracija terminala
GenericName[ca]=Integració del terminal
GenericName[ca@valencia]=Integració del terminal
GenericName[da]=Integration af terminal
GenericName[de]=Terminal-Integration
GenericName[el]=Ενσωμάτωση τερματικού
GenericName[en_GB]=Terminal Integration
GenericName[es]=Integración de la terminal
GenericName[et]=Lõimimine terminaliga
GenericName[fi]=Pääteikkunaintegraatio
GenericName[fr]=Intégration du terminal
GenericName[gl]=Integración co terminal
GenericName[hu]=Terminál integráció
GenericName[it]=Integrazione terminale
GenericName[ja]=ターミナルの統合
GenericName[kk]=Терминалды біріктіру
GenericName[nb]=Terminalintegrering
GenericName[nds]=Konsool-Inbinnen
GenericName[nl]=Terminal-integratie
GenericName[pl]=Integracja terminala
GenericName[pt]=Integração com o Terminal
GenericName[pt_BR]=Integração com o terminal
GenericName[ru]=Интеграция терминала
GenericName[sk]=Integrácia terminálu
GenericName[sl]=Vgrajen terminal
GenericName[sv]=Integrering av terminal
GenericName[tr]=Uçbirim Bütünleşmesi
GenericName[uk]=Інтеграція термінала
GenericName[x-test]=xxTerminal Integrationxx
GenericName[zh_CN]=终端整合
GenericName[zh_TW]=終端機整合
Icon=utilities-terminal
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevkonsoleview
X-KDE-PluginInfo-Name=kdevkonsoleview
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform-1.5.90.tar.xz: kdevplatform-1.5.90/plugins/konsole/kdevkonsoleview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=This plugin provides KDevelop with an embedded konsole for quick and easy command line access.
Comment[bg]=Тaзи приставка осигурява на KDevelop вградена конзола за лесен достъп от команден ред.
Comment[bs]=Ovaj dodatak obezbjeđuje KDvelop sa ugrađenom konzolom za brz i lahak pristup komandnoj liniji.
Comment[ca]=Aquest connector proporciona al KDevelop un Konsole incrustat per accedir de manera ràpida i fàcil a la línia d'ordres.
Comment[ca@valencia]=Este connector proporciona a KDevelop un Konsole incrustat per accedir de manera ràpida i fàcil a la línia d'ordes.
Comment[da]=Dette plugin giver KDevelop en indlejret konsol for hurtig og nem kommandolinje adgang.
Comment[de]=Dieses Modul stattet KDevelop mit einer eingebetteten Konsole zum einfachen Zugriff auf die Befehlszeile aus.
Comment[el]=Αυτό το πρόσθετο προσφέρει στο KDevelop μια ενσωματωμένη konsole για γρήγορη και εύκολη πρόσβαση σε γραμμή εντολών.
Comment[en_GB]=This plugin provides KDevelop with an embedded konsole for quick and easy command line access.
Comment[es]=Este complemento proporciona a KDevelop una consola empotrada para acceder rápida y fácilmente a la línea de órdenes.
Comment[et]=See plugin pakub KDevelopile põimitud konsooli käsurea kiireks ja lihtsaks kasutamiseks.
Comment[fi]=Tämä liitännäinen tarjoaa KDevelop-ohjelmalle upotetun pääteikkunan nopeaan ja helppoon komentorivityöskentelyyn.
Comment[fr]=Ce module externe fournit à KDevelop une console intégrée permettant un accès rapide et aisé à la ligne de commande.
Comment[gl]=Este complemento fornécelle a KDevelop un konsole integrado para dispor de acceso rápido e sinxelo á liña de ordes.
Comment[hu]=Ez a bővítmény szolgáltatja a KDevelopot egy beágyazott konzollal a gyors és könnyű parancssori hozzáféréshez.
Comment[it]=Questa estensione dota KDevelop di una console integrata per una rapido e facile accesso alla riga di comando.
Comment[ja]=コマンドラインに簡単に素早くアクセスできるように KDevelop に組み込み Konsole を提供します
Comment[kk]=Бұл плагині KDevelop құрамына, тез және ыңғайлы командаларды орындау үшін konsole-ді ендіреді.
Comment[nb]=Dette programtillegget gir KDevelop en innebygget konsole for rask og lett tilgang til kommandolinja.
Comment[nds]=Dit Moduul stellt en inbett Konsole för KDevelop praat, wat gau un eenfach Togriep op de Konsool verlöövt.
Comment[nl]=Deze plugin biedt KDevelop een ingebed konsole voor snelle en gemakkelijke toegang tot commandoregels.
Comment[pl]=Ta wtyczka dodaje do KDevelopa wbudowaną konsolę umożliwiając szybki i łatwy dostęp do linii komend.
Comment[pt]=Este 'plugin' oferece ao KDevelop uma consola incorporada para um acesso rápido e simples à linha de comandos.
Comment[pt_BR]=Este plugin fornece ao KDevelop um terminal embutido para acesso rápido e fácil à linha de comando.
Comment[ru]=Это расширение добавляет в KDevelop встроенный терминал для быстрого и лёгкого доступа к командной строке.
Comment[sk]=Tento plugin poskytuje KDevelop so zabudovanou konzolou na rýchly a ľahký prístup k príkazovému riadku.
Comment[sl]=Vstavek v KDevelop prinaša vgrajeno konzolo za hiter in preprost dostop do ukazne vrstice.
Comment[sv]=Insticksprogrammet ger KDevelop en inbyggd terminal för snabb och enkel åtkomst av kommandoraden.
Comment[tr]=Bu eklenti, komut satırına kolayca erişebilmeniz için KDevelop içerisinde gömülü bir uçbirim sağlar.
Comment[uk]=За допомогою цього додатка у KDevelop можна буде скористатися вбудованою konsole, яка пришвидшить і полегшить доступ до командного рядка.
Comment[x-test]=xxThis plugin provides KDevelop with an embedded konsole for quick and easy command line access.xx
Comment[zh_CN]=此插件为 KDevelop 提供了一个快速方便地访问命令行的嵌入式控制台。
Comment[zh_TW]=此外掛程式提供 KDevelop 一個嵌入式的 konsole，能快速地使用命令列。
Name=Konsole Integration
Name[bg]=Интегриране на конзола
Name[bs]=Integracija konzole
Name[ca]=Integració del Konsole
Name[ca@valencia]=Integració del Konsole
Name[da]=Integration af Konsole
Name[de]=Konsole-Integration
Name[el]=Ενσωμάτωση Konsole
Name[en_GB]=Konsole Integration
Name[es]=Integración de la consola
Name[et]=Lõimimine Konsooliga
Name[fi]=Pääteikkunaintegraatio
Name[fr]=Intégration de Konsole
Name[gl]=Integración con Konsole
Name[hu]=Konsole integráció
Name[it]=Integrazione Konsole
Name[ja]=Konsole の統合
Name[kk]=Konsole біріктіруі
Name[nb]=Konsole-integrering
Name[nds]=Konsool-Inbinnen
Name[nl]=Console-integratie
Name[pl]=Integracja Konsoli
Name[pt]=Integração com o Konsole
Name[pt_BR]=Integração com o Konsole
Name[ru]=Интеграция Konsole
Name[sk]=Integrácia Konsole
Name[sl]=Vgrajena konzola
Name[sv]=Integrering av Konsole
Name[tr]=Konsole Bütünleşmesi
Name[ug]=Konsole يۈرۈشلەشتۈرۈلۈشى
Name[uk]=Інтеграція Konsole
Name[x-test]=xxKonsole Integrationxx
Name[zh_CN]=Konsole 整合
Name[zh_TW]=Konsole 整合
GenericName=Terminal Integration
GenericName[bg]=Интегриране на терминал
GenericName[bs]=Integracija terminala
GenericName[ca]=Integració del terminal
GenericName[ca@valencia]=Integració del terminal
GenericName[da]=Integration af terminal
GenericName[de]=Terminal-Integration
GenericName[el]=Ενσωμάτωση τερματικού
GenericName[en_GB]=Terminal Integration
GenericName[es]=Integración de la terminal
GenericName[et]=Lõimimine terminaliga
GenericName[fi]=Pääteikkunaintegraatio
GenericName[fr]=Intégration du terminal
GenericName[gl]=Integración co terminal
GenericName[hu]=Terminál integráció
GenericName[it]=Integrazione terminale
GenericName[ja]=ターミナルの統合
GenericName[kk]=Терминалды біріктіру
GenericName[nb]=Terminalintegrering
GenericName[nds]=Konsool-Inbinnen
GenericName[nl]=Terminal-integratie
GenericName[pl]=Integracja terminala
GenericName[pt]=Integração com o Terminal
GenericName[pt_BR]=Integração com o terminal
GenericName[ru]=Интеграция терминала
GenericName[sk]=Integrácia terminálu
GenericName[sl]=Vgrajen terminal
GenericName[sv]=Integrering av terminal
GenericName[tr]=Uçbirim Bütünleşmesi
GenericName[uk]=Інтеграція термінала
GenericName[x-test]=xxTerminal Integrationxx
GenericName[zh_CN]=终端整合
GenericName[zh_TW]=終端機整合
Icon=utilities-terminal
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevkonsoleview
X-KDE-PluginInfo-Name=kdevkonsoleview
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
